@@ -1,19 +1,21 @@
 DReg.repar <- function(x, Y, X, Z, d, k, w, base, NR){
-
-
-
+################################################################################
+### PREPARATION
+################################################################################
 
   npar <- length(x)
+  seq_along_d <- seq_len(d)
+  seq_along_k <- seq_len(k)
 
   B <- matrix(0, nrow=k, ncol=d)
-  B[cbind(rep(1:k, (d-1)), rep((1:d)[-base], each=k))] <- x[1:((d-1)*k)]
+  B[cbind(rep(seq_along_k, (d-1)), rep(seq_along_d[-base], each=k))] <- x[1:((d-1)*k)]
   
-  g <- matrix(x[((d-1)*k+1):npar], ncol=1)
+  g <- matrix(x[((d-1)*k+1):npar], ncol=1L)
 
-  eps  <- exp(apply(B, 2, function(b){ X%*%b }))
+  eps  <- exp(apply(B, 2L, function(b){ X%*%b }))
   esum <- rowSums(eps)
   
-  mu <- apply(eps, 2, function(x){ x / esum })
+  mu <- apply(eps, 2L, function(x){ x / esum })
 
   f <- exp(Z%*%g)
   
@@ -21,23 +23,23 @@ DReg.repar <- function(x, Y, X, Z, d, k, w, base, NR){
   
 
 
-
-
-
+################################################################################
+### LOG-LIKELIHOOD
+################################################################################
 
   LL <- w*(lgamma(f)-rowSums(lgamma(A))+rowSums((A-1)*log(Y)))
   
 
 
-
-
-
+################################################################################
+### GRADIENT
+################################################################################
 
   gradient <- matrix(NA, nrow=nrow(Y), ncol=npar)
 
   i <- 0
-  for(co in (1:d)[-base]){
-    for(iv in 1:k){
+  for(co in seq_along_d[-base]){
+    for(iv in seq_along_k){
       i <- i + 1
       gradient[,i] <- w * X[,iv] * eps[,co] * f * (
                       + rowSums(eps[,-co,drop=F]) * (log(Y[,co]) - psigamma(A[,co]))
@@ -58,17 +60,17 @@ DReg.repar <- function(x, Y, X, Z, d, k, w, base, NR){
 
 
 
-
-
-
+################################################################################
+### HESSIAN
+################################################################################
 
   if(NR){
 
   if(d == 2){
     eEps <- list(0, 0)
   } else {
-    eEps <- sapply(1:d, function(i){
-              rowSums(combn((1:d)[-i], 2, function(a){
+    eEps <- sapply(seq_along_d, function(i){
+              rowSums(combn(seq_along_d[-i], 2, function(a){
                 eps[,a[1]]*eps[,a[2]]
               }))
             }, simplify=F)
@@ -76,22 +78,22 @@ DReg.repar <- function(x, Y, X, Z, d, k, w, base, NR){
 
   hessian <- matrix(NA, nrow=npar, ncol=npar)
 
-  hessian.ind <- rbind(as.matrix(expand.grid(1:k, (1:d)[-base])[,2:1]), cbind(-1, 1:ncol(Z)))
+  hessian.ind <- rbind(as.matrix(expand.grid(seq_along_k, seq_along_d[-base])[,2:1]), cbind(-1, 1:ncol(Z)))
   
   for(hess.j in 1:npar){
     for(hess.i in 1:npar){
-      if(hess.i < hess.j) next   
+      if(hess.i < hess.j) next
     
       v1 <- hessian.ind[hess.i,2]
       v2 <- hessian.ind[hess.j,2]
       
       derv <- hessian.ind[c(hess.i, hess.j),1]
       
-      
-      
+
+
       if((derv[1] == derv[2]) & all(derv != -1)) {
         derv <- derv[1]
-        nder <- (1:d)[-derv]
+        nder <- seq_along_d[-derv]
 
         hessian[hess.i, hess.j] <-
         sum(w*( -X[,v1]*X[,v2]*f*eps[,derv]*(( 
@@ -110,10 +112,10 @@ DReg.repar <- function(x, Y, X, Z, d, k, w, base, NR){
           - eps[,derv]^2) 
         ))
         ) / esum^4))
-      
-      
+
+
       } else if((derv[1] != derv[2]) & all(derv != -1)) {
-        nder <- (1:d)[-derv]
+        nder <- seq_along_d[-derv]
 
         hessian[hess.i, hess.j] <-
         sum(w*(X[,v1]*X[,v2]*f*eps[,derv[1]]*eps[,derv[2]]*(
@@ -130,11 +132,11 @@ DReg.repar <- function(x, Y, X, Z, d, k, w, base, NR){
           + rowSums(sapply(derv, function(i){ log(Y[,i])*(eps[,i]-rowSums(eps[,-i])) }))
           )    
         ) / esum^4))
-      
-      
+
+
       } else if(any(derv != -1) & any(derv == -1)) {
         derv <- derv[which(derv != -1)]
-        nder <- (1:d)[-derv]
+        nder <- seq_along_d[-derv]
         
         hessian[hess.i, hess.j] <-
         sum(w*(Z[,v1] * X[,v2] * f * eps[,derv] * (
@@ -151,12 +153,12 @@ DReg.repar <- function(x, Y, X, Z, d, k, w, base, NR){
             })) - eps[,derv] * psigamma(A[,derv], 1) * rowSums(eps[,nder,drop=F])  
           )
         ) / esum^3))
-      
-      
+
+
       } else if(all(derv == -1)){
         hessian[hess.i, hess.j] <-
         sum(w*(Z[,v1]*Z[,v2]*f*(
-          rowSums(sapply(1:d, function(i){
+          rowSums(sapply(seq_along_d, function(i){
             eps[,i] * ( log(Y[,i]) - psigamma(A[,i]) - A[,i]*psigamma(A[,i],1) )
           }))
         + esum * (psigamma(f) + f*psigamma(f,1)) 
